@@ -16,7 +16,7 @@ use Data::MuForm::Localizer;
 use MooX::Aliases;
 use Data::MuForm::Merge ('merge');
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 has 'name' => ( is => 'ro', builder => 'build_name');
@@ -535,7 +535,7 @@ Data::MuForm - Data validator and form processor
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -570,7 +570,7 @@ An example of a custom form class:
     extends 'Data::MuForm';
 
     has_field 'name' => ( type => 'Text' );
-    has_field 'age' => ( type => 'Integer', apply => [ 'MinimumAge' ] );
+    has_field 'age' => ( type => 'Integer', apply => [ MinimumAge ] );
     has_field 'hobbies' => ( type => 'Multiple' );
     has_field 'address' => ( type => 'Compound' );
     has_field 'address.city' => ( type => 'Text' );
